@@ -87,7 +87,7 @@ int HLCmdLineApp::printInstalledFiles(const string& where, const string& wildcar
     sort ( filePaths.begin(), filePaths.end() );
     string suffix, desc;
     Diluculum::LuaValueMap categoryMap;
-    cout << "\nInstalled language definitions";
+    cout << "\nInstalled " << kind << "s";
     
     if (categoryFilterList.size())
         cout << " matching \""<<categoryFilterList<<"\"";
@@ -137,7 +137,7 @@ int HLCmdLineApp::printInstalledFiles(const string& where, const string& wildcar
                 cout << setw ( 30 ) <<setiosflags ( ios::left ) <<desc<<": "<<suffix;
             
                 int extCnt=0;
-                for (StringMap::iterator it=assocByExtension.begin(); it!=assocByExtension.end(); it++) {
+                for (StringMap::iterator it=dataDir.assocByExtension.begin(); it!=dataDir.assocByExtension.end(); it++) {
                     if (it->second==suffix ) {
                         cout << ((++extCnt==1)?" ( ":" ")<<it->first;
                     }
@@ -181,24 +181,30 @@ void HLCmdLineApp::printDebugInfo ( const highlight::SyntaxReader *lang,
                                     const string & langDefPath )
 {
     if (!lang) return;
+    
+    map <int, string> HLStateMap;
+    
     cerr << "\nLoading language definition:\n" << langDefPath;
     cerr << "\n\nDescription: " << lang->getDescription();
-
     Diluculum::LuaState* luaState=lang->getLuaState();
     if (luaState) {
         cerr << "\n\nLUA GLOBALS:\n" ;
         Diluculum::LuaValueMap::iterator it;
         Diluculum::LuaValueMap glob =luaState->globals();
+        string elemName;
         for(it = glob.begin(); it != glob.end(); it++) {
             Diluculum::LuaValue first = it->first;
             Diluculum::LuaValue second = it->second;
-            std::cerr << first.asString()<<": ";
+            elemName = first.asString();
+            std::cerr << elemName<<": ";
             switch (second.type()) {
             case  LUA_TSTRING:
                 cerr << "string [ "<<second.asString()<<" ]";
                 break;
             case  LUA_TNUMBER:
                 cerr << "number [ "<<second.asNumber()<<" ]";
+                if (elemName.find("HL_")==0 && elemName.find("HL_FORMAT")==string::npos)
+                    HLStateMap[second.asNumber()] = elemName;
                 break;
             case  LUA_TBOOLEAN:
                 cerr << "boolean [ "<<second.asBoolean()<<" ]";
@@ -211,17 +217,22 @@ void HLCmdLineApp::printDebugInfo ( const highlight::SyntaxReader *lang,
 
     }
     
-    /*cerr << "\nREGEX:\n";
     highlight::RegexElement *re=NULL;
     for ( unsigned int i=0; i<lang->getRegexElements().size(); i++ )
     {
+        if (i==0)
+             cerr << "\nREGEX:\n";
+   
         re = lang->getRegexElements() [i];
-        cerr << "State "<<re->open<<":\t"<<re->rex <<"\n";
-    }*/
-    cerr << "\nKEYWORDS:\n";
+        cerr << "State "<<re->open<< " ("<< HLStateMap[re->open]<<  "):\t"<<re->pattern <<"\n";
+    }
+    
     highlight::KeywordMap::iterator it;
     highlight::KeywordMap keys=lang->getKeywords();
     for ( it=keys.begin(); it!=keys.end(); it++ ) {
+        if (it==keys.begin())
+            cerr << "\nKEYWORDS:\n";
+    
         cerr << " "<< it->first << "("<< it->second << ")";
     }
     cerr <<"\n\n";
@@ -242,60 +253,6 @@ void HLCmdLineApp::printConfigInfo ( )
     cout << endl;
 }
 
-string HLCmdLineApp::getFileBaseName(const string& fileName){
-    size_t psPos = fileName.rfind ( /*Platform::pathSeparator*/ '/' );
-    return  (psPos==string::npos) ? fileName : fileName.substr(psPos+1, fileName.length());
-}
-
-string HLCmdLineApp::getFileSuffix(const string& fileName)
-{
-    size_t ptPos=fileName.rfind(".");
-    size_t psPos = fileName.rfind ( Platform::pathSeparator );
-    if (ptPos == string::npos) {
-        return  (psPos==string::npos) ? fileName : fileName.substr(psPos+1, fileName.length());
-    }
-    return (psPos!=string::npos && psPos>ptPos) ? "" : fileName.substr(ptPos+1, fileName.length());
-}
-
-void HLCmdLineApp::readLuaList(const string& paramName, const string& langName,Diluculum::LuaValue &luaVal, StringMap* extMap){
-    int extIdx=1;
-    string val;
-    while (luaVal[paramName][extIdx] !=Diluculum::Nil) {
-        val = luaVal[paramName][extIdx].asString();
-        extMap->insert ( make_pair ( val,  langName ) );
-        extIdx++;
-    }
-}
-
-bool HLCmdLineApp::loadFileTypeConfig ( const string& confName)
-{
-    string confPath=dataDir.getFiletypesConfPath(confName);
-    try {
-        Diluculum::LuaState ls;
-        Diluculum::LuaValueList ret= ls.doFile (confPath);
-
-        int idx=1;
-        string langName;
-        Diluculum::LuaValue mapEntry;
-        while ((mapEntry = ls["FileMapping"][idx].value()) !=Diluculum::Nil) {
-            langName = mapEntry["Lang"].asString();
-            if (mapEntry["Extensions"] !=Diluculum::Nil) {
-                readLuaList("Extensions", langName, mapEntry,  &assocByExtension);
-            } else if (mapEntry["Filenames"] !=Diluculum::Nil) {
-                readLuaList("Filenames", langName, mapEntry,  &assocByFilename);
-            } else if (mapEntry["Shebang"] !=Diluculum::Nil) {
-                assocByShebang.insert ( make_pair ( mapEntry["Shebang"].asString(),  langName ) );
-            }
-            idx++;
-        }
-
-    } catch (Diluculum::LuaError &err) {
-        cerr <<err.what()<<"\n";
-        return false;
-    }
-    return true;
-}
-
 int HLCmdLineApp::getNumDigits ( int i )
 {
     int res=0;
@@ -353,48 +310,6 @@ void HLCmdLineApp::printIOErrorReport ( unsigned int numberErrorFiles,
     }
 }
 
-string HLCmdLineApp::analyzeFile ( const string& file )
-{
-    string firstLine;
-    if ( !file.empty() ) {
-        ifstream inFile ( file.c_str() );
-        getline ( inFile, firstLine );
-    } else {
-        //  This copies all the data to a new buffer, uses the data to get the
-        //  first line, then makes cin use the new buffer that underlies the
-        //  stringstream instance
-        cin_bufcopy << cin.rdbuf();
-        getline ( cin_bufcopy, firstLine );
-        cin_bufcopy.seekg ( 0, ios::beg );
-        cin.rdbuf ( cin_bufcopy.rdbuf() );
-    }
-    StringMap::iterator it;
-    boost::xpressive::sregex rex;
-    boost::xpressive::smatch what;
-    for ( it=assocByShebang.begin(); it!=assocByShebang.end(); it++ ) {
-        rex = boost::xpressive::sregex::compile( it->first );
-        if ( boost::xpressive::regex_search( firstLine, what, rex )  ) return it->second;
-    }
-    return "";
-}
-
-string HLCmdLineApp::guessFileType ( const string& suffix, const string &inputFile, bool useUserSuffix )
-{
-    string baseName = getFileBaseName(inputFile);
-    if (assocByFilename.count(baseName)) return assocByFilename.find(baseName)->second;
-
-    string lcSuffix = StringTools::change_case(suffix);
-    if (assocByExtension.count(lcSuffix)) {
-        return assocByExtension[lcSuffix];
-    }
-
-    if (!useUserSuffix) {
-        string shebang =  analyzeFile(inputFile);
-        if (!shebang.empty()) return shebang;
-    }
-    return lcSuffix;
-}
-
 vector <string> HLCmdLineApp::collectPluginPaths(const vector<string>& plugins)
 {
     vector<string> absolutePaths;
@@ -432,18 +347,23 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
         return EXIT_SUCCESS;
     }
 
-    if ( options.showThemes() ) {
-        return printInstalledFiles(dataDir.getThemePath(), "*.theme", "theme", OPT_STYLE, options.getCategories());
-    }
-    if ( options.showPlugins() ) {
-        return printInstalledFiles(dataDir.getPluginPath(), "*.lua", "plug-in", OPT_PLUGIN, options.getCategories());
-    }
-
     //call before printInstalledLanguages!
-    loadFileTypeConfig ( "filetypes" );
+    dataDir.loadFileTypeConfig ( "filetypes" );
 
-    if ( options.showLangdefs() ) {
-        return printInstalledFiles(dataDir.getLangPath(), "*.lang", "langDef", OPT_SYNTAX, options.getCategories());
+    string scriptKind=options.getListScriptKind();
+    if (scriptKind.length()) {
+        if ( scriptKind.find("theme")==0 ) {
+            return printInstalledFiles(dataDir.getThemePath(), "*.theme", "theme", OPT_STYLE, options.getCategories());
+        }
+        else if ( scriptKind.find("plug")==0 ) {
+            return printInstalledFiles(dataDir.getPluginPath(), "*.lua", "plug-in", OPT_PLUGIN, options.getCategories());
+        }
+        else if (  scriptKind.find("lang")==0 ) {
+            return printInstalledFiles(dataDir.getLangPath(), "*.lang", "langDef", OPT_SYNTAX, options.getCategories());
+        } else {
+            cerr << "highlight: Unknown script type '"<< scriptKind << "'. Apply one of 'themes', 'langs' or 'plug-ins'.\n";
+            return EXIT_FAILURE;
+        }
     }
 
     const vector <string> inFileList=options.getInputFileNames();
@@ -489,6 +409,7 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
     generator->setPrintZeroes ( options.fillLineNrZeroes() );
     generator->setFragmentCode ( options.fragmentOutput() );
     generator->setOmitVersionComment ( options.omitVersionInfo() );
+    generator->setIsolateTags ( options.isolateTags() );
 
     generator->setKeepInjections ( options.keepInjections());
     generator->setPreformatting ( options.getWrappingStyle(),
@@ -582,14 +503,19 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
     string suffix, lastSuffix;
 
     if ( options.syntaxGiven() ) { // user defined language definition, valid for all files
-        suffix = guessFileType ( options.getSyntax(), "", true );
+        //TODO check for filename given prior to IO redirection
+        //--syntax-by-name overrides --syntax
+        string syntaxByFile=options.getSyntaxByFilename();
+        string testSuffix = syntaxByFile.empty() ? options.getSyntax() : dataDir.getFileSuffix(syntaxByFile); 
+        suffix = dataDir.guessFileType (testSuffix, syntaxByFile, syntaxByFile.empty(), true );         
     }
-
+         
     generator->setFilesCnt(fileCount);
         
     while ( i < fileCount && !initError ) {
+           
         if ( !options.syntaxGiven() ) { // determine file type for each file
-            suffix = guessFileType ( getFileSuffix ( inFileList[i] ), inFileList[i] );
+            suffix = dataDir.guessFileType ( dataDir.getFileSuffix ( inFileList[i] ), inFileList[i] );
         }
         if ( suffix.empty()  && options.forceOutput()) suffix="txt"; //avoid segfault
         if ( suffix.empty() ) {
@@ -603,6 +529,7 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
         }
 
         if ( suffix != lastSuffix ) {
+        
             string langDefPath=options.getAbsLangPath().empty() ? dataDir.getLangPath ( suffix+".lang" ) : options.getAbsLangPath();
 
             highlight::LoadResult loadRes= generator-> loadLanguage( langDefPath );
