@@ -37,9 +37,7 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 #include "platform_fs.h"
 
 #define IO_ERROR_REPORT_LENGTH 5
-#define SHEBANG_CNT 12
 
-typedef map<string, string> StringMap;
 
 /// Main application class of the command line interface
 
@@ -61,8 +59,7 @@ public:
 private:
 
     DataDir dataDir;
-    StringMap assocByExtension, assocByFilename, assocByShebang;
-    stringstream cin_bufcopy;
+    
 
     /** print version info*/
     void printVersionInfo();
@@ -74,12 +71,14 @@ private:
     void printBadInstallationInfo();
 
     /** print input and output errors */
-    void printIOErrorReport ( unsigned int numberErrorFiles, vector<string> & fileList, const string &action );
+    void printIOErrorReport ( unsigned int numberErrorFiles, vector<string> & fileList, 
+                              const string &action );
 
     /** list installed  files
         \return true if files were found
     */
-    int printInstalledFiles(const string& where, const string& wildcard, const string& kind, const string&option, const string& categoryFilterList="");
+    int printInstalledFiles(const string& where, const string& wildcard, const string& kind, 
+                            const string&option, const string& categoryFilterList="");
 
     /** print debug information
         \param  lang language definition
@@ -88,18 +87,6 @@ private:
     void printDebugInfo ( const highlight::SyntaxReader *lang,
                           const string &langDefPath );
 
-    /** \return file extension or the base filename if no extension exists
-    */
-    string getFileSuffix ( const string &fileName );
-
-    /** \return base filename
-    */
-    string getFileBaseName(const string& fileName);
-
-    /** \return file type deferred from extension or file shebang comment
-    */
-    string guessFileType ( const string &suffix, const string &inputFile, bool useUserSuffix=false );
-
     int getNumDigits ( int i );
 
     void printProgressBar ( int total, int count );
@@ -109,14 +96,9 @@ private:
     bool readInputFilePaths ( vector<string> &fileList, string wildcard,
                               bool recursiveSearch );
 
-    string analyzeFile ( const string& file );
-    bool loadFileTypeConfig ( const string& name);
     void printInstalledFiles();
 
     vector <string> collectPluginPaths(const vector<string>& plugins);
-
-    void readLuaList(const string& paramName, const string& langName,Diluculum::LuaValue &luaVal, StringMap* extMap);
-
 };
 
 #endif
