@@ -98,7 +98,6 @@ CodeGenerator * CodeGenerator::getInstance ( OutputType type )
     case ODTFLAT:
         generator = new ODTGenerator();
         break;
-#if !defined (QT)
     case ESC_ANSI:
         generator = new AnsiGenerator();
         break;
@@ -107,7 +106,6 @@ CodeGenerator * CodeGenerator::getInstance ( OutputType type )
         generator = new Xterm256Generator();
         generator->setESCTrueColor(type==ESC_TRUECOLOR);
         break;
-#endif
     default:
         break;
     }
@@ -129,6 +127,7 @@ CodeGenerator::CodeGenerator ( highlight::OutputType type )
      lineNumberFillZeroes ( false ),
      printNewLines(true),
      omitVersionComment(false),
+     isolateTags(false),
      baseFontSize("10"),
      lineNumber ( 0 ),
      lineNumberOffset ( 0 ),
@@ -306,6 +305,16 @@ bool CodeGenerator::getOmitVersionComment ()
     return omitVersionComment;
 }
 
+void CodeGenerator::setIsolateTags ( bool flag )
+{
+    isolateTags=flag;
+}
+
+bool CodeGenerator::getIsolateTags ()
+{
+    return isolateTags;
+}
+
 void CodeGenerator::setBaseFont ( const string& fontName )
 {
     baseFont = fontName;
@@ -629,10 +638,6 @@ SKIP_EMBEDDED:
             if ( regexGroups[oldIndex].state==IDENTIFIER_BEGIN || regexGroups[oldIndex].state==KEYWORD ) {
                 string reservedWord= ( currentSyntax->isIgnoreCase() ) ? StringTools::change_case ( token ) :token;
                 currentKeywordClass=currentSyntax->isKeyword ( reservedWord ); //check in lists (no regex)
-                // for positional Tests; will not be used again for actual input parsing
-                // FIXME not needed?
-                //if (currentKeywordClass)
-                //    regexGroups[oldIndex]=ReGroup ( KEYWORD, reservedWord.size(), currentKeywordClass, "" );  
                 
                 if ( !currentKeywordClass && regexGroups[oldIndex].state==KEYWORD ){
                     currentKeywordClass = regexGroups[oldIndex].kwClass;
@@ -658,6 +663,8 @@ State CodeGenerator::validateState(State newState, State oldState)
         params.push_back(Diluculum::LuaValue(newState));
         params.push_back(Diluculum::LuaValue(token));
         params.push_back(Diluculum::LuaValue(getCurrentKeywordClassId()) );
+        params.push_back(Diluculum::LuaValue(lineNumber) );
+        params.push_back(Diluculum::LuaValue(lineIndex-(unsigned int)token.length()) );
 
         Diluculum::LuaValueList res=
             currentSyntax->getLuaState()->call ( *currentSyntax->getValidateStateChangeFct(),
@@ -668,8 +675,18 @@ State CodeGenerator::validateState(State newState, State oldState)
             State validatedState = (State)res[0].asInteger();
             if ( validatedState== _REJECT) {
                 // proceed using only the first character of the token
-                lineIndex -= (token.length() -1);
-                token=token.substr(0, 1);
+                // TODO evaluate if token clear would be better
+                if (res.size()==1) { 
+                    lineIndex -= (token.length() -1);
+                    token=token.substr(0, 1);
+                }
+                
+                //experimental for slim.lang: evaluate second return arg after _REJECT
+                if (res.size()>=2) {
+                    lineIndex -= (token.length() );
+                    token.clear();
+                    return (State)res[1].asInteger();
+                }
                 return oldState;
             }
             stateTrace.push_back(validatedState);
@@ -1807,6 +1824,7 @@ bool CodeGenerator::processKeywordState ( State myState )
         switch ( newState ) {
         case _WS:
             processWsState();
+            exitState=isolateTags;
             break;
         case _EOL:
             insertLineNumber();
@@ -1843,6 +1861,7 @@ bool CodeGenerator::processNumberState()
         switch ( newState ) {
         case _WS:
             processWsState();
+            exitState=isolateTags;
             break;
         case _EOL:
             insertLineNumber();
@@ -1862,7 +1881,6 @@ bool CodeGenerator::processNumberState()
 }
 
 
-
 bool CodeGenerator::processMultiLineCommentState()
 {
     int commentCount=1;
@@ -1929,10 +1947,6 @@ bool CodeGenerator::processMultiLineCommentState()
 
 bool CodeGenerator::processSingleLineCommentState()
 {
-    if ( checkSpecialCmd() ) {
-        return in->bad(); // if input stream is bad, report eof to calling method
-    }
-
     State newState=STANDARD;
     bool eof=false, exitState=false, containedTestCase=false;
     unsigned int startColumn = lineIndex - token.size() ;
@@ -2114,6 +2128,7 @@ bool CodeGenerator::processStringState ( State oldState )
             openTag ( myState );
             returnedFromOtherState=true;
             break;
+    
         case _EOF:
             eof = true;
             break;
@@ -2142,6 +2157,7 @@ bool CodeGenerator::processSymbolState()
         switch ( newState ) {
         case _WS:
             processWsState();
+            exitState=isolateTags;
             break;
         case _EOL:
             insertLineNumber();
@@ -2175,6 +2191,7 @@ bool CodeGenerator::processEscapeCharState()
             break;
         case _WS:
             processWsState();
+            exitState=isolateTags;
             break;
         case _EOF:
             eof = true;
@@ -2204,6 +2221,7 @@ bool CodeGenerator::processInterpolationState()
             break;
         case _WS:
             processWsState();
+            exitState=isolateTags;
             break;
         case _EOF:
             eof = true;
@@ -2555,24 +2573,4 @@ bool CodeGenerator::initPluginScript(const string& script)
     return true;
 }
 
-bool CodeGenerator::checkSpecialCmd()
-{
-    string noParseCmd="@highlight";
-    size_t cmdPos = line.find ( noParseCmd );
-
-    if ( cmdPos!=string::npos ) {
-        *out<<line.substr ( noParseCmd.size() +cmdPos + 1 );
-
-        // hide comment line from output
-        token.clear();
-        lineIndex=line.length();
-        getInputChar();
-        lineNumber--;
-        // end hide
-
-        return true; // do not parse line as comment
-    }
-    return false; //parse comment as usual
-}
-
 }
