@@ -3,7 +3,7 @@
                              -------------------
     begin                : Wed Nov 28 2001
     copyright            : (C) 2001-2018 by Andre Simon
-    email                : andre.simon1@gmx.de
+    email                : a.simon@mailbox.org
  ***************************************************************************/
 
 /*
@@ -139,6 +139,11 @@ void  SyntaxReader::initLuaState(Diluculum::LuaState& ls, const string& langDefP
     ls["HL_FORMAT_BBCODE"]=BBCODE;
     ls["HL_FORMAT_PANGO"]=PANGO;
     ls["HL_FORMAT_ODT"]=ODTFLAT;
+    
+    // default values for --verbose
+    ls["IgnoreCase"]=false;
+    ls["EnableIndentation"]=false;
+    ls["DisableHighlighting"]=false;
 }
 
 LoadResult SyntaxReader::load ( const string& langDefPath, const string& pluginReadFilePath, OutputType outputType )
@@ -169,6 +174,20 @@ LoadResult SyntaxReader::load ( const string& langDefPath, const string& pluginR
         ls.doFile (langDefPath);
 
         langDesc = ls["Description"].value().asString();
+        
+        if (ls["Categories"].value() !=Diluculum::Nil){
+
+            Diluculum::LuaValueMap categoryMap;
+            categoryMap = ls["Categories"].value().asTable();
+                
+            for(Diluculum::LuaValueMap::const_iterator it = categoryMap.begin(); it != categoryMap.end(); ++it)
+            {
+                categories.append(it->second.asString());
+                if (std::next(it) != categoryMap.end()) {
+                    categories.append(",");
+                }
+            }
+        }
 
         if (pluginChunks.size()) {
             Diluculum::LuaValueList params;
@@ -312,7 +331,6 @@ LoadResult SyntaxReader::load ( const string& langDefPath, const string& pluginR
             string escRegex;
             if (ls["Strings"]["Escape"].value()==Diluculum::Nil){
                 escRegex=REGEX_ESCSEQ;
-                ls["Strings[Escape]"] = escRegex; //for --verbose output
             } else {
                 escRegex=ls["Strings"]["Escape"].value().asString();
             }
