@@ -3,7 +3,7 @@
                              -------------------
     begin                : Mo 16.03.2009
     copyright            : (C) 2009 by Andre Simon
-    email                : andre.simon1@gmx.de
+    email                : a.simon@mailbox.org
  ***************************************************************************/
 
 
