@@ -36,6 +36,9 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 #include "io_report.h"
 #include "syntax_chooser.h"
 
+#ifdef Q_OS_WIN
+#include <windows.h>
+#endif
 //#include <QDebug>
 
 MainWindow::MainWindow(QWidget *parent)
@@ -746,6 +749,14 @@ highlight::OutputType MainWindow::getOutputType()
         return highlight::SVG;
     case 7:
         return highlight::BBCODE;
+
+    case 8:
+        return highlight::ESC_ANSI;
+    case 9:
+        return highlight::ESC_XTERM256;
+    case 10:
+        return highlight::ESC_TRUECOLOR;
+
     }
     return highlight::HTML;
 }
@@ -768,6 +779,10 @@ QString MainWindow::getOutFileSuffix()
         return ".svg";
     case 7:
         return ".bbcode";
+    case 8:
+    case 9:
+    case 10:
+        return ".esc";
     }
     return ".html";
 }
@@ -980,17 +995,23 @@ void MainWindow::on_pbStartConversion_clicked()
     QString langDefPath;
     QString userLangPath = getUserScriptPath("lang");
 
-    QString inFileName, inFilePath;
+    QString inFileName, inFilePath, origFilePath;
     QString lastStyleDestDir;
     QSet<QString> usedFileNames;
 
     QStringList inputErrors, outputErrors, reformatErrors, syntaxTestErrors;
 
     for (int i=0; i<ui->lvInputFiles->count(); i++) {
-        inFilePath =  ui->lvInputFiles->item(i)->data(Qt::UserRole).toString();
+        inFilePath = origFilePath =  ui->lvInputFiles->item(i)->data(Qt::UserRole).toString();
+
+#ifdef Q_OS_WIN
+
+        inFilePath = getWindowsShortPath(inFilePath);
+
+#endif
         currentFile = inFilePath.toStdString();
 
-        statusBar()->showMessage(tr("Processing %1 (%2/%3)").arg(inFilePath).arg(i+1).arg(ui->lvInputFiles->count()));
+        statusBar()->showMessage(tr("Processing %1 (%2/%3)").arg(origFilePath).arg(i+1).arg(ui->lvInputFiles->count()));
 
         langDefPath = (userLangPath.isEmpty()) ? getDistLangPath(getFileType(getFileSuffix(currentFile), currentFile)) : userLangPath;
 
@@ -1001,11 +1022,11 @@ void MainWindow::on_pbStartConversion_clicked()
                                      QString::fromStdString( generator->getSyntaxRegexError())));
             break;
         } else  if (loadRes==highlight::LOAD_FAILED) {
-            QMessageBox::warning(this, tr("Unknown syntax"), tr("Could not convert %1").arg(inFilePath));
-            inputErrors.append(inFilePath);
+            QMessageBox::warning(this, tr("Unknown syntax"), tr("Could not convert %1").arg(origFilePath));
+            inputErrors.append(origFilePath);
         } else  if (loadRes==highlight::LOAD_FAILED_LUA) {
-            QMessageBox::warning(this, tr("Lua error"), tr("Could not convert %1:\nLua Syntax error: %2").arg(inFilePath).arg(QString::fromStdString(generator->getSyntaxLuaError())) );
-            inputErrors.append(inFilePath);
+            QMessageBox::warning(this, tr("Lua error"), tr("Could not convert %1:\nLua Syntax error: %2").arg(origFilePath).arg(QString::fromStdString(generator->getSyntaxLuaError())) );
+            inputErrors.append(origFilePath);
         } else {
 
             if (ui->cbReformat->isChecked()&& !generator->formattingIsPossible()) {
@@ -1013,23 +1034,49 @@ void MainWindow::on_pbStartConversion_clicked()
             }
 
             inFileName = ui->lvInputFiles->item(i)->text(); // QFileInfo(inFilePath).fileName();
-
             if (ui->cbWrite2Src->isChecked()) {
-                outfileName = currentFile;
+                //outfileName = currentFile + getOutFileSuffix().toStdString();
+
+                QString absOutPath=origFilePath + getOutFileSuffix();
+
+#ifdef Q_OS_WIN
+                QFile file( absOutPath );
+                if ( file.open(QIODevice::ReadWrite) )
+                {
+                    absOutPath = getWindowsShortPath(absOutPath);
+                }
+#endif
+                outfileName = absOutPath.toStdString();
             } else {
                 QFileInfo outFileInfo;
                 QString fName=inFileName;
                 if (usedFileNames.contains(fName)) {
+
                     QString prefix=QFileInfo(inFilePath).canonicalPath()+ QDir::separator();
-                    prefix.replace(QDir::separator(), '_');
+#ifdef Q_OS_WIN
+                    prefix.remove(0,2); // Get rid of drive letter and ':'
+#endif
+                    prefix.replace('/', '_');
+                    prefix.replace('\\', '_');
                     fName.insert(0, prefix);
+
                 } else {
                     usedFileNames.insert(fName);
                 }
                 outFileInfo.setFile(ui->leOutputDest->text(),fName);
-                outfileName = outFileInfo.absoluteFilePath().toStdString();
+
+                QString absOutPath=outFileInfo.absoluteFilePath() + getOutFileSuffix();
+
+#ifdef Q_OS_WIN
+                QFile file( absOutPath );
+                if ( file.open(QIODevice::ReadWrite) )
+                {
+                    absOutPath = getWindowsShortPath(absOutPath);
+                }
+#endif
+                outfileName = absOutPath.toStdString();
             }
-            outfileName +=  getOutFileSuffix().toStdString();
+            //outfileName +=  getOutFileSuffix().toStdString();
 
             if (ui->cbHTMLFileNameAnchor->isChecked()) {
                 generator->setHTMLAnchorPrefix(inFileName.toStdString());
@@ -1038,9 +1085,9 @@ void MainWindow::on_pbStartConversion_clicked()
             error = generator->generateFile(currentFile, outfileName );
             if (error != highlight::PARSE_OK) {
                 if (error == highlight::BAD_INPUT) {
-                    inputErrors.append(inFilePath);
+                    inputErrors.append(origFilePath);
                 } else {
-                    outputErrors.append(inFilePath);
+                    outputErrors.append(origFilePath);
                 }
             }
             ui->progressBar->setValue(100*i / ui->lvInputFiles->count());
@@ -1054,6 +1101,14 @@ void MainWindow::on_pbStartConversion_clicked()
             if (lastStyleDestDir!=styleDestDir){
                 lastStyleDestDir = styleDestDir;
                 QString stylePath=QFileInfo(styleDestDir, leStyleFile->text()).absoluteFilePath();
+
+#ifdef Q_OS_WIN
+                QFile file( stylePath );
+                if ( file.open(QIODevice::ReadWrite) )
+                {
+                    stylePath = getWindowsShortPath(stylePath);
+                }
+#endif
                 bool styleFileOK=generator -> printExternalStyle(QDir::toNativeSeparators(stylePath).toStdString());
                 if (!styleFileOK) {
                     outputErrors.append(stylePath);
@@ -1071,9 +1126,19 @@ void MainWindow::on_pbStartConversion_clicked()
         }
         QString outPath = QDir::toNativeSeparators(ui->leOutputDest->text());
         if (!outPath.endsWith(QDir::separator())) outPath.append(QDir::separator());
-        bool indexFileOK=generator->printIndexFile(fileList,  outPath.toStdString());
+        outPath.append("index");
+        outPath.append(getOutFileSuffix());
+#ifdef Q_OS_WIN
+                QFile file( outPath );
+                if ( file.open(QIODevice::ReadWrite) )
+                {
+                    outPath = getWindowsShortPath(outPath);
+                }
+#endif
+
+        bool indexFileOK=generator->printIndexFile(fileList, outPath.toStdString());
         if (!indexFileOK) {
-            outputErrors.append(outPath+ ((outType==highlight::HTML)?"index.html":"index.xhtml"));
+            outputErrors.append(outPath);
         }
     }
 
@@ -1138,6 +1203,7 @@ void MainWindow::highlight2Clipboard(bool getDataFromCP)
     QString previewFilePath = (getDataFromCP) ? "": ui->lvInputFiles->currentItem()->data(Qt::UserRole).toString();
 
     if (getDataFromCP) {
+
         suffix= getFileType((ui->comboSelectSyntax->itemData(ui->comboSelectSyntax->currentIndex())).toString().toStdString(),"");
 
         if (ui->cbCopyRange->isEnabled() && ui->cbCopyRange->isChecked()) {
@@ -1157,6 +1223,13 @@ void MainWindow::highlight2Clipboard(bool getDataFromCP)
             }
         }
     } else {
+
+#ifdef Q_OS_WIN
+
+        previewFilePath = getWindowsShortPath(previewFilePath);
+
+#endif
+
         string currentFile = previewFilePath.toStdString();
         suffix = getFileType(getFileSuffix(currentFile), currentFile);
 
@@ -1182,7 +1255,7 @@ void MainWindow::highlight2Clipboard(bool getDataFromCP)
             highlight::OutputType outputType = getOutputType();
             if ( outputType==highlight::RTF) {
                 QMimeData *mimeData = new QMimeData();
-#ifdef Q_OS_WIN32
+#ifdef Q_OS_WIN
                 mimeData->setData("Rich Text Format", clipBoardData.toLatin1());
 #else
                 mimeData->setData("text/rtf", clipBoardData.toLatin1());
@@ -1301,6 +1374,12 @@ void MainWindow::updatePreview()
     QString previewInputPath = (getDataFromCP) ? "" : ui->lvInputFiles->currentItem()->data(Qt::UserRole).toString();
     QString croppedName = QFileInfo(previewInputPath).fileName();
 
+#ifdef Q_OS_WIN
+
+        previewInputPath = getWindowsShortPath(previewInputPath);
+
+#endif
+
     if (getDataFromCP) {
         suffix= getFileType((ui->comboSelectSyntax->itemData(ui->comboSelectSyntax->currentIndex())).toString().toStdString(),"");
     } else {
@@ -1672,3 +1751,16 @@ void MainWindow::on_comboThemeFilter_currentIndexChanged(int index)
     if (ui->comboTheme->count())
         fillThemeCombo(0);
 }
+
+QString MainWindow::getWindowsShortPath(const QString & path){
+    QString shortPath(path);
+#ifdef Q_OS_WIN
+        int length = GetShortPathName( (const wchar_t*)path.utf16(),0,0);
+        wchar_t* buffer = new wchar_t[length];
+
+        length = GetShortPathName( (const wchar_t*)path.utf16(), buffer, length);
+        shortPath = QString::fromUtf16((const char16_t*)buffer, length);
+        delete[] buffer;
+#endif
+    return shortPath;
+}
