@@ -3,7 +3,7 @@
                              -------------------
     begin                : Die Jul 9 2002
     copyright            : (C) 2002-2018 by Andre Simon
-    email                : andre.simon1@gmx.de
+    email                : a.simon@mailbox.org
  ***************************************************************************/
 
 
@@ -304,12 +304,18 @@ public:
     /** return number wrapped lines flag */
     bool getNumberWrappedLines ();
     
-    /** \param  flag true if version info comment should be omitted */
+    /** \param flag true if version info comment should be omitted */
     void setOmitVersionComment ( bool flag );
 
     /** return version info comment flag */
     bool getOmitVersionComment ();
     
+    /** \param flag true if token of the same syntax category should be outputted in separate tags */
+    void setIsolateTags ( bool flag );
+
+    /** return version info comment flag */
+    bool getIsolateTags ();
+    
     /** \return style path */
     const string& getStyleName();
 
@@ -409,6 +415,12 @@ public:
     /** \return Theme description */
     string getThemeDescription();
 
+    /** \return Syntaxreader category description */
+    string getSyntaxCatDescription();
+
+    /** \return Theme category description */
+    string getThemeCatDescription();
+
     vector<string> getPosTestErrors() { return failedPosTests; }
     
     /** \return Pointer Syntaxreader, intended for debug output  */
@@ -578,6 +590,9 @@ protected:
     /** Test if version info comment printed */
     bool omitVersionComment;
     
+    /** Flag to output token of the same syntax category in separate tags */
+    bool isolateTags;
+    
     /** The base font to use */
     string baseFont ;
 
@@ -887,9 +902,10 @@ private:
     /** call user script OnStateChange function if defined to confirm state change
      \param newState new state
      \param oldState old state
-     \param kwClass keyword class ID if newState is KEYWORD
      */
-    State validateState(State newState, State oldState, unsigned int kwClass);
+    State validateState(State newState, State oldState);
+    
+    unsigned int getCurrentKeywordClassId();
   
     string getParam(const string& arg, const char* op);
     string getParam(const string& arg, const char* op1, const char* op2);
@@ -909,9 +925,6 @@ private:
     void applyPluginChunk(const string& fctName, string *result, bool *keepDefault);
     
     static vector<Diluculum::LuaFunction*> pluginChunks;
-    
-    /** \deprecated replace by Lua functionality */
-    bool checkSpecialCmd();
 };
 
 }
