@@ -3,7 +3,7 @@
                              -------------------
     begin                : Mon Dec 10 2001
     copyright            : (C) 2001-2010 by Andre Simon
-    email                : andre.simon1@gmx.de
+    email                : a.simon@mailbox.org
  ***************************************************************************/
 
 
@@ -84,6 +84,8 @@ bool str2num ( T &val, const std::string& s, std::ios_base& ( *f ) ( std::ios_ba
 int calcWeight(const string&s);
 
 string getPathAcronym(const string&path, char delim);
+
+bool endsWith(std::string const & value, std::string const & ending);
 }
 
 #endif
