@@ -3,7 +3,7 @@
                              -------------------
     begin                : Mit Jul 24 2002
     copyright            : (C) 2002 by Andrï¿½Simon
-    email                : andre.simon1@gmx.de
+    email                : a.simon@mailbox.org
  ***************************************************************************/
 
 
